@@ -32,4 +32,7 @@ pub mod script;
 pub use script::*;
 
 pub mod hash;
-pub use hash::*;
\ No newline at end of file
+pub use hash::*;
+
+pub mod encryption;
+pub use encryption::*;
\ No newline at end of file
